About
=====

Authors
-------

``fastobo`` is developped and maintained by:

+-------------------------------------------------+
| | **Martin Larralde**                           |
| | PhD Candidate, Zeller Team                    |
| | EMBL Heidelberg                               |
| | martin.larralde@embl.de                       |
+-------------------------------------------------+

This library was developped during a Master's internship at
**Lawrence Berkeley National Laboratory**, under the supervision of:

+-------------------------------------------------+
| | **Chris Mungall**                             |
| | Department Head, Molecular Ecosystems Biology |
| | Lawrence Berkeley National Laboratory         |
| | cjmungall@lbl.gov                             |
+-------------------------------------------------+


Citation
--------

This library was created by one of your colleagues. Please acknowledge the
Principal Investigator, and cite the reference document in which it was
described:

*Larralde M.* **Developing Python and Rust libraries to improve the ontology ecosystem**
*\[version 1; not peer reviewed\].* F1000Research 2019, 8(ISCB Comm J):1500 (poster)
(`https://doi.org/10.7490/f1000research.1117405.1 <https://doi.org/10.7490/f1000research.1117405.1>`_)



License
-------

This project is licensed under the `MIT License <https://choosealicense.com/licenses/mit/>`_.
